;;
;; Boulder Dash 2 C64 music
;;
;; 1. Converted with midi2ay: $ midi2ay -asm boulder2.mid
;; 2. Replaced sound routine with
;;    https://cpctech.cpc-live.com/source/midi2ay.html
;; 3. Adapted for WinAPE (replaced xxh with #xx)
;;
;; save"boulder2.mus",b,&8000,&8AF4-&8000

;; Midi2ay playback code for Amstrad CPC
;;
;; Uses firmware functions to allow music to play
;; while BASIC is active.
;;
;; CALL &8000 to setup interrupt and to play music
;; CALL &8003 to stop music
;; 
;;
;; Code assembles using wincpc's assembler.
;;
;; To use this:
;; 1. Use Midi2ay to convert a .mid file and output as asm.
;; 2. Delete the data after notas in this file.
;; 3. Copy and paste the notas from the new asm file to the end of this code
;; 4. Assemble and enjoy.
;;
;; NOTE: The tone data stored here is for the Spectrum which
;; has an AY sound chip running at 1.77Mhz.
;;
;; The CPC has an AY sound chip running at 1.0Mhz, so the tones will not 
;; be correct.

;;--------------------------------------------------------------------------------------------

kl_new_frame_fly equ &bcd7
mc_sound_register equ &bd34
kl_del_frame_fly equ &bcdd
;;--------------------------------------------------------------------------------------------

org #8000


;;--------------------------------------------------------------------------------------------

jp play_music       ;; +0
jp stop_music       ;; +3

;;--------------------------------------------------------------------------------------------

play_music:
xor a
ld (counter),a
ld (count_active),a

;; setup an interrupt to be executed every frame flyback 
;; (50hz)
ld hl,ff_event_block
ld b,&81
ld c,0
ld de,ff_event_routine
call kl_new_frame_fly
ret

;;--------------------------------------------------------------------------------------------

stop_music:
ld hl,ff_event_block
call kl_del_frame_fly
ret

;;--------------------------------------------------------------------------------------------

ff_event_block:
defs 10

;;--------------------------------------------------------------------------------------------

ff_event_routine:
;; counter is active?

ld a,(count_active)
or a
;; no, do next packet
jr z,packet_begin

;; yes it's active
;; count down
ld a,(counter)
dec a
ld (counter),a

;; if counter is not zero, we quit and continue
or a
ret nz

;; counter is not active any more
xor a
ld (count_active),a

;; we now continue from counter and read remaining data in packet
ld hl,(pos)
jr cont_from_counter

;;--------------------------------------------------------------------------------------------

;; read a complete packet 
packet_begin:
ld  hl,(pos)

;; continue with part of a packet
packet_cont:

;; counter?
ld  a,(hl)
or  a
jr  nz,counter_set

;; continue after doing a counter
cont_from_counter:
inc hl
ld  a,(hl)
cp  #ff        ;; end
jr  z,music_end
cp  #fe        ;; skip?
jr  z,skip
    
;; write to ay
ld a,(hl)
inc hl
ld c,(hl)
inc hl
call mc_sound_register
        
jr  packet_cont

;;--------------------------------------------------------------------------------------------
;; start the counter

counter_set:
ld  (pos),hl
ld (counter),a
ld (count_active),a

ret

;;--------------------------------------------------------------------------------------------
;; skip data

skip:   
inc hl
inc hl
ld  (pos),hl
ret

;;--------------------------------------------------------------------------------------------
;; music end

music_end:
;; loop
ld hl,notas
ld (pos),hl
jr packet_cont

;;--------------------------------------------------------------------------------------------

count_active: defb 0
counter: defb 0
pos:    dw  notas

;;--------------------------------------------------------------------------------------------


;; data

notas:

    db  #000, #007, #038, #000, #008, #000, #000, #009, #000
    db  #000, #010, #000, #000, #000, #08d, #000, #001, #000
    db  #000, #008, #00f, #000, #002, #0f5, #000, #003, #004
    db  #000, #009, #00f, #000, #004, #08d, #000, #005, #000
    db  #007, #008, #000, #000, #009, #000, #001, #000, #09f
    db  #000, #008, #00f, #000, #002, #0bd, #000, #003, #000
    db  #000, #009, #00f, #008, #008, #000, #000, #009, #000
    db  #001, #000, #08d, #000, #008, #00f, #000, #002, #0b2
    db  #000, #009, #00f, #000, #004, #09f, #008, #008, #000
    db  #000, #009, #000, #001, #000, #07e, #000, #008, #00f
    db  #000, #002, #0f5, #000, #003, #004, #000, #009, #00f
    db  #000, #004, #08d, #008, #008, #000, #000, #009, #000
    db  #001, #000, #077, #000, #008, #00f, #000, #002, #0db
    db  #000, #003, #001, #000, #009, #00f, #000, #004, #07e
    db  #008, #008, #000, #000, #009, #000, #001, #000, #059
    db  #000, #008, #00f, #000, #002, #077, #000, #003, #000
    db  #000, #009, #00f, #000, #004, #077, #008, #008, #000
    db  #000, #009, #000, #001, #000, #05e, #000, #008, #00f
    db  #000, #009, #00f, #000, #004, #059, #008, #008, #000
    db  #000, #009, #000, #001, #000, #04f, #000, #008, #00f
    db  #000, #002, #07b, #000, #003, #002, #000, #009, #00f
    db  #000, #004, #05e, #008, #008, #000, #000, #009, #000
    db  #001, #000, #077, #000, #008, #00f, #000, #002, #0b7
    db  #000, #003, #003, #000, #009, #00f, #000, #004, #04f
    db  #008, #008, #000, #000, #009, #000, #001, #000, #09f
    db  #000, #008, #00f, #000, #009, #00f, #000, #004, #077
    db  #008, #008, #000, #000, #009, #000, #001, #000, #05e
    db  #000, #008, #00f, #000, #009, #00f, #000, #004, #09f
    db  #008, #008, #000, #000, #009, #000, #001, #000, #09f
    db  #000, #008, #00f, #000, #009, #00f, #000, #004, #05e
    db  #008, #008, #000, #000, #009, #000, #001, #000, #04f
    db  #000, #008, #00f, #000, #002, #07b, #000, #003, #002
    db  #000, #009, #00f, #000, #004, #09f, #008, #008, #000
    db  #000, #009, #000, #001, #000, #08d, #000, #008, #00f
    db  #000, #009, #00f, #000, #004, #04f, #008, #008, #000
    db  #000, #009, #000, #001, #000, #04f, #000, #008, #00f
    db  #000, #002, #0f5, #000, #003, #004, #000, #009, #00f
    db  #000, #004, #08d, #008, #008, #000, #000, #009, #000
    db  #001, #000, #09f, #000, #008, #00f, #000, #009, #00f
    db  #000, #004, #04f, #008, #008, #000, #000, #009, #000
    db  #001, #000, #08d, #000, #008, #00f, #000, #009, #00f
    db  #000, #004, #09f, #008, #008, #000, #000, #009, #000
    db  #001, #000, #09f, #000, #008, #00f, #000, #002, #0bd
    db  #000, #003, #000, #000, #009, #00f, #000, #004, #08d
    db  #008, #008, #000, #000, #009, #000, #001, #000, #08d
    db  #000, #008, #00f, #000, #002, #0b2, #000, #009, #00f
    db  #000, #004, #09f, #008, #008, #000, #000, #009, #000
    db  #001, #000, #07e, #000, #008, #00f, #000, #002, #0f5
    db  #000, #003, #004, #000, #009, #00f, #000, #004, #08d
    db  #008, #008, #000, #000, #009, #000, #001, #000, #077
    db  #000, #008, #00f, #000, #002, #0db, #000, #003, #001
    db  #000, #009, #00f, #000, #004, #07e, #008, #008, #000
    db  #000, #009, #000, #001, #000, #059, #000, #008, #00f
    db  #000, #002, #077, #000, #003, #000, #000, #009, #00f
    db  #000, #004, #077, #008, #008, #000, #000, #009, #000
    db  #001, #000, #05e, #000, #008, #00f, #000, #009, #00f
    db  #000, #004, #059, #008, #008, #000, #000, #009, #000
    db  #001, #000, #04f, #000, #008, #00f, #000, #002, #07b
    db  #000, #003, #002, #000, #009, #00f, #000, #004, #05e
    db  #008, #008, #000, #000, #009, #000, #001, #000, #077
    db  #000, #008, #00f, #000, #002, #0b7, #000, #003, #003
    db  #000, #009, #00f, #000, #004, #04f, #008, #008, #000
    db  #000, #009, #000, #001, #000, #09f, #000, #008, #00f
    db  #000, #009, #00f, #000, #004, #077, #008, #008, #000
    db  #000, #009, #000, #001, #000, #05e, #000, #008, #00f
    db  #000, #009, #00f, #000, #004, #09f, #008, #008, #000
    db  #000, #009, #000, #001, #000, #09f, #000, #008, #00f
    db  #000, #009, #00f, #000, #004, #05e, #008, #008, #000
    db  #000, #009, #000, #001, #000, #04f, #000, #008, #00f
    db  #000, #002, #07b, #000, #003, #002, #000, #009, #00f
    db  #000, #004, #09f, #008, #008, #000, #000, #009, #000
    db  #001, #000, #08d, #000, #008, #00f, #000, #009, #00f
    db  #000, #004, #04f, #008, #008, #000, #000, #009, #000
    db  #001, #000, #04f, #000, #008, #00f, #000, #002, #0f5
    db  #000, #003, #004, #000, #009, #00f, #000, #004, #08d
    db  #008, #008, #000, #000, #009, #000, #001, #000, #09f
    db  #000, #008, #00f, #000, #009, #00f, #000, #004, #04f
    db  #008, #008, #000, #000, #009, #000, #001, #000, #0db
    db  #000, #001, #001, #000, #008, #00f, #000, #002, #02b
    db  #000, #009, #00f, #000, #004, #09f, #008, #008, #000
    db  #000, #009, #000, #001, #000, #0ee, #000, #001, #000
    db  #000, #008, #00f, #000, #002, #064, #000, #003, #001
    db  #000, #009, #00f, #000, #004, #0db, #000, #005, #001
    db  #008, #008, #000, #000, #009, #000, #001, #000, #01b
    db  #000, #001, #001, #000, #008, #00f, #000, #002, #04f
    db  #000, #003, #003, #000, #009, #00f, #000, #004, #0ee
    db  #000, #005, #000, #008, #008, #000, #000, #009, #000
    db  #001, #000, #08d, #000, #001, #000, #000, #008, #00f
    db  #000, #002, #0d4, #000, #003, #000, #000, #009, #00f
    db  #000, #004, #01b, #000, #005, #001, #008, #008, #000
    db  #000, #009, #000, #001, #000, #0b2, #000, #008, #00f
    db  #000, #002, #016, #000, #003, #002, #000, #009, #00f
    db  #000, #004, #08d, #000, #005, #000, #008, #008, #000
    db  #000, #009, #000, #001, #000, #077, #000, #008, #00f
    db  #000, #002, #08d, #000, #003, #000, #000, #009, #00f
    db  #000, #004, #0b2, #008, #008, #000, #000, #009, #000
    db  #001, #000, #06a, #000, #008, #00f, #000, #002, #02b
    db  #000, #003, #004, #000, #009, #00f, #000, #004, #077
    db  #008, #008, #000, #000, #009, #000, #001, #000, #05e
    db  #000, #008, #00f, #000, #002, #077, #000, #003, #000
    db  #000, #009, #00f, #000, #004, #06a, #008, #008, #000
    db  #000, #009, #000, #001, #000, #077, #000, #008, #00f
    db  #000, #002, #064, #000, #003, #001, #000, #009, #00f
    db  #000, #004, #05e, #008, #008, #000, #000, #009, #000
    db  #001, #008, #00f, #000, #009, #00f, #000, #004, #077
    db  #008, #008, #000, #000, #009, #000, #001, #000, #08d
    db  #000, #008, #00f, #000, #009, #00f, #008, #008, #000
    db  #000, #009, #000, #001, #008, #00f, #000, #009, #00f
    db  #000, #004, #08d, #008, #008, #000, #000, #009, #000
    db  #001, #000, #09f, #000, #008, #00f, #000, #002, #0db
    db  #000, #009, #00f, #008, #008, #000, #000, #009, #000
    db  #001, #008, #00f, #000, #009, #00f, #000, #004, #09f
    db  #008, #008, #000, #000, #009, #000, #001, #000, #0b2
    db  #000, #008, #00f, #000, #002, #0c8, #000, #003, #002
    db  #000, #009, #00f, #008, #008, #000, #000, #009, #000
    db  #001, #008, #00f, #000, #009, #00f, #000, #004, #0b2
    db  #008, #008, #000, #000, #009, #000, #001, #000, #08d
    db  #000, #008, #00f, #000, #002, #0f5, #000, #003, #004
    db  #000, #009, #00f, #008, #008, #000, #000, #009, #000
    db  #001, #000, #09f, #000, #008, #00f, #000, #002, #0bd
    db  #000, #003, #000, #000, #009, #00f, #000, #004, #08d
    db  #008, #008, #000, #000, #009, #000, #001, #000, #08d
    db  #000, #008, #00f, #000, #002, #0b2, #000, #009, #00f
    db  #000, #004, #09f, #008, #008, #000, #000, #009, #000
    db  #001, #000, #07e, #000, #008, #00f, #000, #002, #0f5
    db  #000, #003, #004, #000, #009, #00f, #000, #004, #08d
    db  #008, #008, #000, #000, #009, #000, #001, #000, #077
    db  #000, #008, #00f, #000, #002, #0db, #000, #003, #001
    db  #000, #009, #00f, #000, #004, #07e, #008, #008, #000
    db  #000, #009, #000, #001, #000, #059, #000, #008, #00f
    db  #000, #002, #077, #000, #003, #000, #000, #009, #00f
    db  #000, #004, #077, #008, #008, #000, #000, #009, #000
    db  #001, #000, #05e, #000, #008, #00f, #000, #009, #00f
    db  #000, #004, #059, #008, #008, #000, #000, #009, #000
    db  #001, #000, #04f, #000, #008, #00f, #000, #002, #07b
    db  #000, #003, #002, #000, #009, #00f, #000, #004, #05e
    db  #008, #008, #000, #000, #009, #000, #001, #000, #077
    db  #000, #008, #00f, #000, #002, #0b7, #000, #003, #003
    db  #000, #009, #00f, #000, #004, #04f, #008, #008, #000
    db  #000, #009, #000, #001, #000, #09f, #000, #008, #00f
    db  #000, #009, #00f, #000, #004, #077, #008, #008, #000
    db  #000, #009, #000, #001, #000, #05e, #000, #008, #00f
    db  #000, #009, #00f, #000, #004, #09f, #008, #008, #000
    db  #000, #009, #000, #001, #000, #09f, #000, #008, #00f
    db  #000, #009, #00f, #000, #004, #05e, #008, #008, #000
    db  #000, #009, #000, #001, #000, #04f, #000, #008, #00f
    db  #000, #002, #07b, #000, #003, #002, #000, #009, #00f
    db  #000, #004, #09f, #008, #008, #000, #000, #009, #000
    db  #001, #000, #08d, #000, #008, #00f, #000, #009, #00f
    db  #000, #004, #04f, #008, #008, #000, #000, #009, #000
    db  #001, #000, #04f, #000, #008, #00f, #000, #002, #0f5
    db  #000, #003, #004, #000, #009, #00f, #000, #004, #08d
    db  #008, #008, #000, #000, #009, #000, #001, #000, #09f
    db  #000, #008, #00f, #000, #009, #00f, #000, #004, #04f
    db  #008, #008, #000, #000, #009, #000, #001, #000, #03d
    db  #000, #001, #001, #000, #008, #00f, #000, #002, #0db
    db  #000, #003, #001, #000, #009, #00f, #000, #004, #09f
    db  #008, #008, #000, #000, #009, #000, #001, #008, #00f
    db  #000, #009, #00f, #000, #004, #03d, #000, #005, #001
    db  #008, #008, #000, #000, #009, #000, #001, #000, #01b
    db  #000, #008, #00f, #000, #009, #00f, #008, #008, #000
    db  #000, #009, #000, #001, #008, #00f, #000, #009, #00f
    db  #000, #004, #01b, #008, #008, #000, #000, #009, #000
    db  #001, #000, #0ee, #000, #001, #000, #000, #008, #00f
    db  #000, #009, #00f, #008, #008, #000, #000, #009, #000
    db  #001, #008, #00f, #000, #009, #00f, #000, #004, #0ee
    db  #000, #005, #000, #008, #008, #000, #000, #009, #000
    db  #001, #000, #0b2, #000, #008, #00f, #000, #009, #00f
    db  #008, #008, #000, #000, #009, #000, #001, #008, #00f
    db  #000, #009, #00f, #000, #004, #0b2, #008, #008, #000
    db  #000, #009, #000, #001, #000, #03d, #000, #001, #001
    db  #000, #008, #00f, #000, #002, #016, #000, #003, #002
    db  #000, #009, #00f, #008, #008, #000, #000, #009, #000
    db  #001, #008, #00f, #000, #009, #00f, #000, #004, #03d
    db  #000, #005, #001, #008, #008, #000, #000, #009, #000
    db  #001, #000, #01b, #000, #008, #00f, #000, #009, #00f
    db  #008, #008, #000, #000, #009, #000, #001, #008, #00f
    db  #000, #009, #00f, #000, #004, #01b, #008, #008, #000
    db  #000, #009, #000, #001, #000, #0ee, #000, #001, #000
    db  #000, #008, #00f, #000, #002, #07b, #000, #009, #00f
    db  #008, #008, #000, #000, #009, #000, #001, #008, #00f
    db  #000, #009, #00f, #000, #004, #0ee, #000, #005, #000
    db  #008, #008, #000, #000, #009, #000, #001, #000, #0d4
    db  #000, #008, #00f, #000, #002, #0c8, #000, #009, #00f
    db  #008, #008, #000, #000, #009, #000, #001, #008, #00f
    db  #000, #009, #00f, #000, #004, #0d4, #008, #008, #000
    db  #000, #009, #000, #001, #000, #03d, #000, #001, #001
    db  #000, #008, #00f, #000, #002, #0db, #000, #003, #001
    db  #000, #009, #00f, #008, #008, #000, #000, #009, #000
    db  #001, #008, #00f, #000, #009, #00f, #000, #004, #03d
    db  #000, #005, #001, #008, #008, #000, #000, #009, #000
    db  #001, #000, #01b, #000, #008, #00f, #000, #009, #00f
    db  #008, #008, #000, #000, #009, #000, #001, #008, #00f
    db  #000, #009, #00f, #000, #004, #01b, #008, #008, #000
    db  #000, #009, #000, #001, #000, #0ee, #000, #001, #000
    db  #000, #008, #00f, #000, #009, #00f, #008, #008, #000
    db  #000, #009, #000, #001, #008, #00f, #000, #009, #00f
    db  #000, #004, #0ee, #000, #005, #000, #008, #008, #000
    db  #000, #009, #000, #001, #000, #0b2, #000, #008, #00f
    db  #000, #009, #00f, #008, #008, #000, #000, #009, #000
    db  #001, #008, #00f, #000, #009, #00f, #000, #004, #0b2
    db  #008, #008, #000, #000, #009, #000, #001, #000, #03d
    db  #000, #001, #001, #000, #008, #00f, #000, #002, #07b
    db  #000, #003, #002, #000, #009, #00f, #008, #008, #000
    db  #000, #009, #000, #001, #000, #09f, #000, #001, #000
    db  #000, #008, #00f, #000, #002, #0d4, #000, #003, #000
    db  #000, #009, #00f, #000, #004, #03d, #000, #005, #001
    db  #008, #008, #000, #000, #009, #000, #001, #008, #00f
    db  #000, #009, #00f, #000, #004, #09f, #000, #005, #000
    db  #008, #008, #000, #000, #009, #000, #001, #008, #00f
    db  #000, #009, #00f, #008, #008, #000, #000, #009, #000
    db  #001, #008, #00f, #000, #009, #00f, #008, #008, #000
    db  #000, #009, #000, #001, #008, #00f, #000, #009, #00f
    db  #008, #008, #000, #000, #009, #000, #001, #000, #03d
    db  #000, #001, #001, #000, #008, #00f, #000, #002, #07b
    db  #000, #003, #002, #000, #009, #00f, #008, #008, #000
    db  #000, #009, #000, #001, #008, #00f, #000, #009, #00f
    db  #000, #004, #03d, #000, #005, #001, #008, #008, #000
    db  #000, #009, #000, #001, #000, #08d, #000, #001, #000
    db  #000, #008, #00f, #000, #002, #0f5, #000, #003, #004
    db  #000, #009, #00f, #008, #008, #000, #000, #009, #000
    db  #001, #000, #09f, #000, #008, #00f, #000, #002, #0bd
    db  #000, #003, #000, #000, #009, #00f, #000, #004, #08d
    db  #000, #005, #000, #008, #008, #000, #000, #009, #000
    db  #001, #000, #08d, #000, #008, #00f, #000, #002, #0b2
    db  #000, #009, #00f, #000, #004, #09f, #008, #008, #000
    db  #000, #009, #000, #001, #000, #07e, #000, #008, #00f
    db  #000, #002, #0f5, #000, #003, #004, #000, #009, #00f
    db  #000, #004, #08d, #008, #008, #000, #000, #009, #000
    db  #001, #000, #077, #000, #008, #00f, #000, #002, #0db
    db  #000, #003, #001, #000, #009, #00f, #000, #004, #07e
    db  #008, #008, #000, #000, #009, #000, #001, #000, #059
    db  #000, #008, #00f, #000, #002, #077, #000, #003, #000
    db  #000, #009, #00f, #000, #004, #077, #008, #008, #000
    db  #000, #009, #000, #001, #000, #05e, #000, #008, #00f
    db  #000, #009, #00f, #000, #004, #059, #008, #008, #000
    db  #000, #009, #000, #001, #000, #04f, #000, #008, #00f
    db  #000, #002, #07b, #000, #003, #002, #000, #009, #00f
    db  #000, #004, #05e, #008, #008, #000, #000, #009, #000
    db  #001, #000, #077, #000, #008, #00f, #000, #002, #0b7
    db  #000, #003, #003, #000, #009, #00f, #000, #004, #04f
    db  #008, #008, #000, #000, #009, #000, #001, #000, #09f
    db  #000, #008, #00f, #000, #009, #00f, #000, #004, #077
    db  #008, #008, #000, #000, #009, #000, #001, #000, #05e
    db  #000, #008, #00f, #000, #009, #00f, #000, #004, #09f
    db  #008, #008, #000, #000, #009, #000, #001, #000, #09f
    db  #000, #008, #00f, #000, #009, #00f, #000, #004, #05e
    db  #008, #008, #000, #000, #009, #000, #001, #000, #04f
    db  #000, #008, #00f, #000, #002, #07b, #000, #003, #002
    db  #000, #009, #00f, #000, #004, #09f, #008, #008, #000
    db  #000, #009, #000, #001, #000, #08d, #000, #008, #00f
    db  #000, #002, #04f, #000, #003, #000, #000, #004, #07b
    db  #000, #005, #002, #008, #008, #000, #001, #000, #04f
    db  #000, #008, #00f, #000, #002, #0f5, #000, #003, #004
    db  #000, #009, #00f, #000, #004, #08d, #000, #005, #000
    db  #008, #008, #000, #000, #009, #000, #001, #000, #09f
    db  #000, #008, #00f, #000, #002, #04f, #000, #003, #000
    db  #000, #004, #0f5, #000, #005, #004, #008, #008, #000
    db  #001, #000, #08d, #000, #008, #00f, #000, #002, #0f5
    db  #000, #003, #004, #000, #009, #00f, #000, #004, #09f
    db  #000, #005, #000, #008, #008, #000, #000, #009, #000
    db  #001, #000, #09f, #000, #008, #00f, #000, #002, #0bd
    db  #000, #003, #000, #000, #009, #00f, #000, #004, #08d
    db  #008, #008, #000, #000, #009, #000, #001, #000, #08d
    db  #000, #008, #00f, #000, #002, #0b2, #000, #009, #00f
    db  #000, #004, #09f, #008, #008, #000, #000, #009, #000
    db  #001, #000, #07e, #000, #008, #00f, #000, #002, #0f5
    db  #000, #003, #004, #000, #009, #00f, #000, #004, #08d
    db  #008, #008, #000, #000, #009, #000, #001, #000, #077
    db  #000, #008, #00f, #000, #002, #0db, #000, #003, #001
    db  #000, #009, #00f, #000, #004, #07e, #008, #008, #000
    db  #000, #009, #000, #001, #000, #059, #000, #008, #00f
    db  #000, #002, #077, #000, #003, #000, #000, #009, #00f
    db  #000, #004, #077, #008, #008, #000, #000, #009, #000
    db  #001, #000, #05e, #000, #008, #00f, #000, #009, #00f
    db  #000, #004, #059, #008, #008, #000, #000, #009, #000
    db  #001, #000, #04f, #000, #008, #00f, #000, #002, #07b
    db  #000, #003, #002, #000, #009, #00f, #000, #004, #05e
    db  #008, #008, #000, #000, #009, #000, #001, #000, #077
    db  #000, #008, #00f, #000, #002, #0b7, #000, #003, #003
    db  #000, #009, #00f, #000, #004, #04f, #008, #008, #000
    db  #000, #009, #000, #001, #000, #09f, #000, #008, #00f
    db  #000, #009, #00f, #000, #004, #077, #008, #008, #000
    db  #000, #009, #000, #001, #000, #05e, #000, #008, #00f
    db  #000, #009, #00f, #000, #004, #09f, #008, #008, #000
    db  #000, #009, #000, #001, #000, #09f, #000, #008, #00f
    db  #000, #009, #00f, #000, #004, #05e, #008, #008, #000
    db  #000, #009, #000, #001, #000, #04f, #000, #008, #00f
    db  #000, #002, #07b, #000, #003, #002, #000, #009, #00f
    db  #000, #004, #09f, #008, #008, #000, #000, #009, #000
    db  #001, #000, #08d, #000, #008, #00f, #000, #002, #04f
    db  #000, #003, #000, #000, #004, #07b, #000, #005, #002
    db  #008, #008, #000, #001, #000, #04f, #000, #008, #00f
    db  #000, #002, #0f5, #000, #003, #004, #000, #009, #00f
    db  #000, #004, #08d, #000, #005, #000, #008, #008, #000
    db  #000, #009, #000, #001, #000, #09f, #000, #008, #00f
    db  #000, #002, #04f, #000, #003, #000, #000, #004, #0f5
    db  #000, #005, #004, #008, #008, #000, #000, #0ff, #000

